@@ -24,19 +24,23 @@
 #include <pulsar/c/reader.h>
 #include <pulsar/c/reader_configuration.h>
 #include <pulsar/c/message_id.h>
+#include "ReaderListener.h"
 
 class ReaderConfig {
  public:
-  ReaderConfig(const Napi::Object &readerConfig);
+  ReaderConfig(const Napi::Object &readerConfig, std::shared_ptr<CReaderWrapper> readerWrapper,
+               pulsar_reader_listener readerListener);
   ~ReaderConfig();
   pulsar_reader_configuration_t *GetCReaderConfig();
   pulsar_message_id_t *GetCStartMessageId();
   std::string GetTopic();
+  ReaderListenerCallback *GetListenerCallback();
 
  private:
   std::string topic;
   pulsar_message_id_t *cStartMessageId;
   pulsar_reader_configuration_t *cReaderConfig;
+  ReaderListenerCallback *listener;
 };
 
 #endif
